@@ -75,4 +75,8 @@ get '/' => sub {
 END
 };
 
-true;
+get '/say_hi' => sub {
+    $_->send([ "Hello!" ]) for websocket_connections;
+};
+
+1;
